@@ -24,9 +24,10 @@ from ead2.backend.config.config import debug
 list_mime_filename = navigation_filters['list_mime']
 
 
-zone_indices = {'pedago':1, 'admin':0}
-zone_msg = {'pedago':t.get_zone_libelle('2').lower(),
-            'admin':t.get_zone_libelle('1').lower()}
+zone_indices = {'pedago':1, 'admin':0, 'web3':2}
+zone_msg = {'pedago':t.get_zone_libelle(2).lower(),
+            'admin':t.get_zone_libelle(1).lower(),
+            'web3':t.get_zone_libelle(3).lower()}
 
 list_msg = {'whitelist':'liste des domaines autorisés',
             'blacklist':'liste des domaines interdits',
@@ -129,7 +130,7 @@ def get_filtrage_form(zone):
     """
     def get_dans_status(zone):
         if isfile(dans_status % zone):
-            return file(dans_status % zone).read()
+            return open(dans_status % zone).read()
         else:
             # la valeur par defaut dans les templates
             return '1'
@@ -204,7 +205,7 @@ def get_mime_form(zone):
 def get_listed(zone, keyword='blacklist'):
     """ renvoie les données pour la liste des sites autorisés/interdits """
     sites = dans_tools.load_site_list(keyword=keyword, zone=zone_indices[zone])
-    keys = sites.keys()
+    keys = list(sites.keys())
     keys.sort()
 
     listed = []
@@ -241,7 +242,7 @@ def get_forbidden_extension(zone):
         de modification des listes locales d'extensions interdites
     """
     exts = dans_tools.load_site_list(keyword='extension', zone=zone_indices[zone])
-    keys = exts.keys()
+    keys = list(exts.keys())
     keys.sort()
 
     ext_table = []
@@ -275,7 +276,7 @@ def get_forbidden_mimes(zone):
         de modification des types mime
     """
     mimes = dans_tools.load_site_list(keyword='mime', zone=zone_indices[zone])
-    keys = mimes.keys()
+    keys = list(mimes.keys())
     keys.sort()
 
     mime_table = []
@@ -335,7 +336,7 @@ def valid_filtrage_form(form_result, zone):
     """ valide la configuration du filtrage web
     """
     def save_dans_status(status, zone):
-        status_f = file(dans_status%zone_indices[zone], 'w')
+        status_f = open(dans_status%zone_indices[zone], 'w')
         status_f.write(status)
         status_f.close()
 
@@ -384,27 +385,27 @@ def valid_sitelist_form(form_result, zone, keyword):
 
     if keyword == 'whitelist':
         antikeyword = 'blacklist'
-        if site in dans_tools.load_site_list(antikeyword,
-                                             zone_indices[zone]).keys():
+        if site in list(dans_tools.load_site_list(antikeyword,
+                                             zone_indices[zone]).keys()):
             antilisted = dans_tools.load_site_list(antikeyword,
                                                    zone_indices[zone])[site]
     else:
         antikeyword = 'whitelist'
-        if site in dans_tools.load_site_list(antikeyword,
-                                             zone_indices[zone]).keys():
+        if site in list(dans_tools.load_site_list(antikeyword,
+                                             zone_indices[zone]).keys()):
             antilisted = dans_tools.load_site_list(antikeyword,
                                                    zone_indices[zone])[site]
 
 
     listed = dans_tools.load_site_list(keyword, zone_indices[zone])
 
-    if site in listed.keys():
+    if site in list(listed.keys()):
         policies_checked = listed[site]
     else:
         policies_checked = [0 for i in dans_tools.columns_list]
 
     for index, policy in enumerate(dans_tools.columns_libelle):
-        if resultat.has_key(str(index)):
+        if str(index) in resultat:
             if resultat[str(index)]:
                 if antilisted[index] == 1:
                     raise Exception("Veuillez supprimer ce site de %s \
@@ -425,7 +426,7 @@ def valid_mod_list(data_names, data_table, zone, keyword):
     """ valide la modification du tableau des sites
         (blacklists, whitelists, types mime, extensions)
     """
-    datas = tools.format_form_result(data_names).keys()
+    datas = list(tools.format_form_result(data_names).keys())
     checked = tools.format_form_result(data_table, True)
 
     data_list = {}
@@ -441,8 +442,8 @@ def valid_mod_list(data_names, data_table, zone, keyword):
             antikeyword = 'blacklist'
         else:
             antikeyword = 'whitelist'
-        if data in dans_tools.load_site_list(antikeyword,
-                                             zone_indices[zone]).keys():
+        if data in list(dans_tools.load_site_list(antikeyword,
+                                             zone_indices[zone]).keys()):
             antilisted = dans_tools.load_site_list(antikeyword,
                                                    zone_indices[zone])[data]
 
@@ -482,13 +483,13 @@ def valid_extension_form(form_result, zone):
 
     forbidden_extensions = dans_tools.load_site_list('extension',
                                                      zone_indices[zone])
-    if extension in forbidden_extensions.keys():
+    if extension in list(forbidden_extensions.keys()):
         policies_checked = forbidden_extensions[extension]
     else:
         policies_checked = [0 for i in dans_tools.columns_list]
 
     for index, policy in enumerate(dans_tools.columns_list):
-        if resultat.has_key(str(index)):
+        if str(index) in resultat:
             if resultat[str(index)]:
                 policies_checked[index] = 1
             if debug:
@@ -518,13 +519,13 @@ def valid_mime_form(form_result, zone):
 
     forbidden_mimes = dans_tools.load_site_list('mime',
                                                 zone_indices[zone])
-    if mime in forbidden_mimes.keys():
+    if mime in list(forbidden_mimes.keys()):
         policies_checked = forbidden_mimes[mime]
     else:
         policies_checked = [0 for i in dans_tools.columns_list]
 
     for index, policy in enumerate(dans_tools.columns_list):
-        if resultat.has_key(str(index)):
+        if str(index) in resultat:
             if resultat[str(index)]:
                 policies_checked[index] = 1
             if debug:
