@@ -4,13 +4,15 @@ from twisted.python import log
 from ead2.backend.actions import tools
 from amon.guardian import dans_tools, config # import set_policy, get_policies, unset_policy
 from ead2.backend.actions.amon.groupe_form import policies_libelles
+from ead2.config.config import SQUID_MITM
+
 
 ## code couleur pour les utilisateurs spéciaux
 policies_colors = {2:'#cfffba', 3:'#ffaeae', 4:'#ffffff'}
 
 ## interface -> navigation_user.py -> user.py (formulaire, action) -> guardian
 libelles = {'add':"Login de l'utilisateur à gérer sur le filtre web %s"}
-zone_indices = {'admin':0, 'pedago':1}
+zone_indices = {'admin':0, 'pedago':1, 'web3':2}
 
 messages = {'mod':"L'utilisateur %s est désormais %s.",
             'del':"La référence à l'utilisateur %s a été supprimée.",
@@ -33,7 +35,7 @@ def get_users(zone_indice):
     if type(zone_indice) != int:
         zone_indice = zone_indices[zone_indice]
     users = []
-    for user_list in dans_tools.get_policies(zone_indice).values():
+    for user_list in list(dans_tools.get_policies(zone_indice).values()):
         users.extend(user_list)
     users.sort()
     return users
@@ -59,7 +61,7 @@ def get_list(zone, server_nb, action):
         user_policy = dans_tools.get_policy(zone_indice, user)
         select_policy = policy_form(zone, server_nb, action, user, user_policy)
         suppr_btn = _get_del_btn(server_nb, action, user)
-        if user_policy in policies_colors.keys():
+        if user_policy in list(policies_colors.keys()):
             listing.append((libelle, select_policy, suppr_btn, policies_colors[user_policy]))
         else:
             listing.append((libelle, select_policy, suppr_btn, ''))
@@ -76,6 +78,9 @@ def policy_form(zone, server_nb, action, user, user_policy):
     options = [{'name': str(policy), 'libelle': policies_libelles[policy-1]}for policy in config.policies]
     if user_policy:
         options[user_policy-1]['default'] = 'ok'
+    if not SQUID_MITM:
+        del options[1] #supprime mode modérateur
+        del options[2] #supprime mode liste blanche
     select_policy = {'onchange':tools.make_js_link(server_nb, action, code=True, balise="user_msg",
                                                     policy='this.options[this.selectedIndex].value',
                                                     user="'%s'"%user),
@@ -117,9 +122,9 @@ def add_user(zone, result):
     zone_indice = zone_indices[zone]
     login = result['name']
     if not tools.test_login(login):
-        raise Exception, 'Le login ne doit contenir que les caratères de a à z, de 0 à 9 et -_.'
+        raise Exception('Le login ne doit contenir que les caratères de a à z, de 0 à 9 et -_.')
     if login in get_users(zone_indice):
-        raise Exception, 'Ce login est déjà référencé.'
+        raise Exception('Ce login est déjà référencé.')
 
     dans_tools.set_policy(zone_indice, 1, login, _type='user')
     message = messages['add']%(login)
@@ -132,7 +137,7 @@ def del_user(zone, login):
     """
     zone_indice = zone_indices[zone]
     if not tools.test_login(login):
-        raise Exception, 'Le login ne doit contenir que les caratères de a à z, de 0 à 9 et -_.'
+        raise Exception('Le login ne doit contenir que les caratères de a à z, de 0 à 9 et -_.')
 
     dans_tools.unset_policy(zone_indice, login, _type='user')
     message = messages['del']%(login)
@@ -141,7 +146,7 @@ def del_user(zone, login):
         message += "\\nLe filtre a bien été rechargé."
     else:
         log.err("Erreur au lancement de service eole-guardian reload(1) dans user.py")
-        raise Exception, "%s\\n Erreur au rechargement du filtre."%message
+        raise Exception("%s\\n Erreur au rechargement du filtre."%message)
     return dict()#message = message)
 
 def mod_user(zone, policy, login):
@@ -153,10 +158,10 @@ def mod_user(zone, policy, login):
     if type(policy) == str:
         policy = int(policy)
     if policy not in config.policies:
-        raise Exception, "Erreur d'indice pour la politique à appliquer."
+        raise Exception("Erreur d'indice pour la politique à appliquer.")
 
     if not tools.test_login(login):
-        raise Exception, 'Le login ne doit contenir que les caratères de a à z, de 0 à 9 et -_.'
+        raise Exception('Le login ne doit contenir que les caratères de a à z, de 0 à 9 et -_.')
 
     dans_tools.set_policy(zone_indice, policy, login, _type='user')
     message = messages['mod']%(login, policies_libelles[policy-1])
@@ -165,7 +170,7 @@ def mod_user(zone, policy, login):
         message += "\\nLe filtre a bien été rechargé."
     else:
         log.err("Erreur au lancement de service eole-guardian reload(1) dans user.py")
-        raise Exception, "%s\\n Erreur au rechargement du filtre."%message
+        raise Exception("%s\\n Erreur au rechargement du filtre."%message)
 
     return dict(message = message)
 
